@@ -12,18 +12,22 @@
 
 """DressingMode"""
 
-from enum import StrEnum
-from typing import Literal, TypeAlias
+from __future__ import annotations
+
+from enum import Enum
+from typing import Literal, Union
+
+from ..aliases import TypeAlias
 
 
-class DressingMode(StrEnum):
+class DressingMode(str, Enum):
     """Which side of a box to anchor the dressing gates to."""
 
     LEFT = "left"
     RIGHT = "right"
 
 
-DressingLiteral: TypeAlias = DressingMode | Literal["left", "right"]
+DressingLiteral: TypeAlias = Union[DressingMode, Literal["left", "right"]]
 """Allowed box dressing modes.
 
  * ``left``: Gate collection templates are placed on the left side of boxes.
