@@ -20,6 +20,11 @@ from ..aliases import StrRef
 class InjectNoise(Annotation):
     """Directive to inject noise into a ``box`` instruction.
 
+    The resulting :class:`~.Samplex` built from a circuit with a box with this annotation requires
+    a :class:`qiskit.quantum_info.PauliLindbladMap` with ``ref`` to at sample time. The qubits of
+    the map are indexed in physical qubit order, in other words, the order of the qubits in the
+    outer-most circuit, restricted to those used by the box.
+
     Args:
         ref: A unique identifier of the map from which to inject noise.
         modifier_ref: A unique identifer for modifiers to apply to the noise map before injection.
