@@ -12,9 +12,7 @@
 
 """ParamIter"""
 
-from typing import Self
-
-from qiskit.circuit import Parameter
+from ..aliases import Parameter, Self
 
 
 class ParamIter:
