@@ -12,6 +12,8 @@
 
 """PreSamplex"""
 
+from __future__ import annotations
+
 from collections import defaultdict
 from collections.abc import Iterable, Iterator, Sequence
 from dataclasses import dataclass
@@ -74,8 +76,9 @@ from ..samplex.nodes.pauli_past_clifford_node import (
     PAULI_PAST_CLIFFORD_INVARIANTS,
     PAULI_PAST_CLIFFORD_LOOKUP_TABLES,
 )
+from ..samplex.noise_model_requirement import NoiseModelRequirement
 from ..synths import Synth
-from ..tensor_interface import Specification, TensorSpecification, ValueType
+from ..tensor_interface import TensorSpecification
 from ..virtual_registers import U2Register
 from ..visualization import plot_graph
 from .graph_data import (
@@ -119,7 +122,7 @@ class DanglerMatch:
     Set to `None` to get all node directions. Note that setting to `BOTH` will only match nodes
     with `BOTH` direction."""
 
-    node_types: type[PreNode] | None = None
+    node_types: tuple[type[PreNode], ...] | None = None
     """The desired type of the node.
 
     Set to `None` to get all node types."""
@@ -177,7 +180,7 @@ class PreSamplex:
         cregs: list[ClassicalRegister] | None = None,
         noise_map_count: count | None = None,
         noise_maps: dict[str, NumSubsystems] | None = None,
-        noise_modifiers: set[str] | None = None,
+        noise_modifiers: dict[str, set[str]] | None = None,
         basis_transforms: dict[str, int] | None = None,
         twirled_clbits: set[ClbitIndex] | None = None,
         passthrough_params: ParamSpec | None = None,
@@ -194,7 +197,7 @@ class PreSamplex:
         self._cregs = cregs
         self._noise_map_count = count() if noise_map_count is None else noise_map_count
         self._noise_maps = {} if noise_maps is None else noise_maps
-        self._noise_modifiers = set() if noise_modifiers is None else noise_modifiers
+        self._noise_modifiers = defaultdict(set) if noise_modifiers is None else noise_modifiers
         self._basis_transforms = {} if basis_transforms is None else basis_transforms
         self._twirled_clbits = set() if twirled_clbits is None else twirled_clbits
         self.passthrough_params: ParamSpec = (
@@ -204,7 +207,7 @@ class PreSamplex:
             set() if forced_copy_node_idxs is None else forced_copy_node_idxs
         )
 
-    def remap(self, qubit_map: dict[Qubit, QubitIndex]) -> "PreSamplex":
+    def remap(self, qubit_map: dict[Qubit, QubitIndex]) -> PreSamplex:
         """Remap the object to a new :class:`~.PreSamplex` object.
 
         Args:
@@ -351,7 +354,7 @@ class PreSamplex:
         # in the future when we have multi-qubit virtual groups, this can't be hard-coded to 1
         subsystems = QubitIndicesPartition(1, [(self.qubit_map[qubit],) for qubit in instr.qubits])
 
-        match = DanglerMatch(node_types=PreEmit | PrePropagate, direction=Direction.RIGHT)
+        match = DanglerMatch(node_types=(PreEmit, PrePropagate), direction=Direction.RIGHT)
         if any(True for _ in self.find_danglers(match, subsystems)):
             raise SamplexBuildError(f"Cannot propagate through {instr.operation.name} instruction.")
         match = DanglerMatch(direction=Direction.LEFT)
@@ -429,7 +432,7 @@ class PreSamplex:
             )
 
         # collect any nodes that need collecting and unmark them as dangling
-        match = DanglerMatch(node_types=PreEmit | PrePropagate, direction=Direction.RIGHT)
+        match = DanglerMatch(node_types=(PreEmit, PrePropagate), direction=Direction.RIGHT)
         for found_idx, found_subsystems in self.find_then_remove_danglers(match, subsystems):
             if self.graph.has_edge(found_idx, node_idx):
                 # The force_register_copy stays the same and doesn't need update.
@@ -447,7 +450,7 @@ class PreSamplex:
         # this collection is in the way
         all(
             self.find_then_remove_danglers(
-                DanglerMatch(node_types=PreCollect | PrePropagate), subsystems
+                DanglerMatch(node_types=(PreCollect, PrePropagate)), subsystems
             )
         )
 
@@ -495,7 +498,7 @@ class PreSamplex:
         # Collect relevant nodes which are an optional dangler, and leave them optionally dangling
         # This needs to happen first, so the new optional danglers created later won't be counted.
         match = DanglerMatch(
-            node_types=PreEmit | PrePropagate,
+            node_types=(PreEmit, PrePropagate),
             direction=Direction.RIGHT,
             dangler_type=DanglerType.OPTIONAL,
         )
@@ -507,7 +510,7 @@ class PreSamplex:
         # Collect every relevant node which is a required dangler,
         # then convert it to an optional dangler.
         match = DanglerMatch(
-            node_types=PreEmit | PrePropagate,
+            node_types=(PreEmit, PrePropagate),
             direction=Direction.RIGHT,
             dangler_type=DanglerType.REQUIRED,
         )
@@ -519,7 +522,7 @@ class PreSamplex:
 
         # Remove previous Pre-Collects from the danglers. They can no longer be reached,
         # because the measurement blocks the way.
-        match = DanglerMatch(node_types=PreCollect, direction=Direction.RIGHT)
+        match = DanglerMatch(node_types=(PreCollect,), direction=Direction.RIGHT)
         all(self.find_then_remove_danglers(match, subsystems))
 
         # Verify that all measurements were reached by an emission
@@ -553,7 +556,7 @@ class PreSamplex:
         # connect this emmision there. we do NOT want to remove them as dangling because they
         # might need to be used again for future emissions, for example, a Pauli twirl followed by
         # a noise injection.
-        match = DanglerMatch(node_types=PreCollect | PrePropagate, direction=Direction.LEFT)
+        match = DanglerMatch(node_types=(PreCollect, PrePropagate), direction=Direction.LEFT)
 
         aggregate_found_subsystems = set()
         for found_idx, found_subsystems in self.find_danglers(match, subsystems):
@@ -581,7 +584,7 @@ class PreSamplex:
         This method adds edges to any node that is dangling with overlapping subsystems.
         """
         node_idx = self.graph.add_node(node)
-        match = DanglerMatch(node_types=PreCollect | PrePropagate, direction=Direction.LEFT)
+        match = DanglerMatch(node_types=(PreCollect, PrePropagate), direction=Direction.LEFT)
         for found_idx, found_subsystems in self.find_danglers(match, node.subsystems):
             self.graph.add_edge(node_idx, found_idx, PreEdge(found_subsystems, Direction.LEFT))
 
@@ -621,7 +624,9 @@ class PreSamplex:
             )
         else:
             self._noise_maps[noise_ref] = len(qubits)
-        self._noise_modifiers.add(modifier_ref)
+
+        if modifier_ref:
+            self._noise_modifiers[noise_ref].add(modifier_ref)
 
         subsystems = self.qubits_to_indices(qubits)
         node = PreInjectNoise(
@@ -658,7 +663,9 @@ class PreSamplex:
             )
         else:
             self._noise_maps[noise_ref] = len(qubits)
-        self._noise_modifiers.add(modifier_ref)
+
+        if modifier_ref:
+            self._noise_modifiers[noise_ref].add(modifier_ref)
 
         subsystems = self.qubits_to_indices(qubits)
         node = PreInjectNoise(
@@ -766,7 +773,7 @@ class PreSamplex:
         rightward_node_candidate = NodeCandidate(
             self.graph, PrePropagate(subsystems, Direction.RIGHT, op, partition, spec)
         )
-        match = DanglerMatch(node_types=PreEmit | PrePropagate, direction=Direction.RIGHT)
+        match = DanglerMatch(node_types=(PreEmit, PrePropagate), direction=Direction.RIGHT)
         all_found_qubit_idxs = set()
         for found_idx, found_subsystems in self.find_then_remove_danglers(match, subsystems):
             all_found_qubit_idxs.update(found_subsystems.all_elements)
@@ -788,7 +795,7 @@ class PreSamplex:
             self.graph, PrePropagate(subsystems, Direction.LEFT, op, partition, spec)
         )
         all_found_qubit_idxs = set()
-        match = DanglerMatch(node_types=PreCollect | PrePropagate, direction=Direction.LEFT)
+        match = DanglerMatch(node_types=(PreCollect, PrePropagate), direction=Direction.LEFT)
         for found_idx, found_subsystems in self.find_then_remove_danglers(match, subsystems):
             all_found_qubit_idxs.update(found_subsystems.all_elements)
             edge = PreEdge(
@@ -954,7 +961,7 @@ class PreSamplex:
         Raises:
             SamplexBuildError: If any nodes are expecting collections.
         """
-        match = DanglerMatch(node_types=PreEmit | PrePropagate, direction=Direction.RIGHT)
+        match = DanglerMatch(node_types=(PreEmit, PrePropagate), direction=Direction.RIGHT)
         uncollected_qubit_idxs = set()
         for qubit_idx, node_idxs in self._dangling.items():
             for node_idx in node_idxs:
@@ -1086,35 +1093,9 @@ class PreSamplex:
                 )
             )
 
-        for noise_map, length in self._noise_maps.items():
-            samplex.add_input(
-                Specification(
-                    f"noise_maps.{noise_map}",
-                    ValueType.LINDBLAD,
-                    f"A noise map acting on ``{length}`` qubits.",
-                )
-            )
-
-        for noise_modifier in self._noise_modifiers:
-            if noise_modifier == "":
-                continue
-
-            samplex.add_input(
-                TensorSpecification(
-                    f"noise_scales.{noise_modifier}",
-                    (),
-                    np.dtype(np.float64),
-                    "A factor by which to scale a noise map.",
-                    optional=True,
-                )
-            )
-            samplex.add_input(
-                Specification(
-                    f"local_scales.{noise_modifier}",
-                    ValueType.NUMPY_ARRAY,
-                    "An array of factors by which to scale individual elements of a noise map.",
-                    True,
-                )
+        for noise_ref, num_qubits in self._noise_maps.items():
+            samplex.add_noise_model_requirement(
+                NoiseModelRequirement(noise_ref, num_qubits, self._noise_modifiers[noise_ref])
             )
 
         if max_param_idx is not None:
@@ -1122,7 +1103,7 @@ class PreSamplex:
                 TensorSpecification(
                     "parameter_values",
                     (max_param_idx + 1,),
-                    np.dtype(np.float64),
+                    np.dtype(np.float32),
                     "Parameter values for the template circuit.",
                 )
             )
@@ -1132,7 +1113,7 @@ class PreSamplex:
                 samplex.add_output(
                     TensorSpecification(
                         f"measurement_flips.{reg.name}",
-                        (len(reg),),
+                        (1, len(reg)),
                         np.dtype(np.bool_),
                         "Bit-flip corrections for measurement twirling.",
                     )
@@ -1212,7 +1193,7 @@ class PreSamplex:
         node = InjectNoiseNode(
             reg_name,
             sign_reg_name,
-            "noise_maps." + pre_inject.ref,
+            pre_inject.ref,
             len(pre_inject.subsystems),
             pre_inject.modifier_ref,
         )
@@ -1538,7 +1519,7 @@ class PreSamplex:
         cols: int = 2,
         subgraph_idxs: None | int | Sequence[int] = None,
         layout_method: LayoutPresets | LayoutMethod = "auto",
-    ) -> "Figure":
+    ) -> Figure:
         """Draw the graph in this pre-samplex using the :meth:`~plot_graph` method.
 
         Args:
